import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface LocallySignedCertConfig extends cdktf.TerraformMetaArguments {
    /**
    * Uses that are allowed for the certificate
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/tls/r/locally_signed_cert#allowed_uses LocallySignedCert#allowed_uses}
    */
    readonly allowedUses: string[];
    /**
    * PEM-encoded CA certificate
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/tls/r/locally_signed_cert#ca_cert_pem LocallySignedCert#ca_cert_pem}
    */
    readonly caCertPem: string;
    /**
    * Name of the algorithm used to generate the certificate's private key
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/tls/r/locally_signed_cert#ca_key_algorithm LocallySignedCert#ca_key_algorithm}
    */
    readonly caKeyAlgorithm: string;
    /**
    * PEM-encoded CA private key used to sign the certificate
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/tls/r/locally_signed_cert#ca_private_key_pem LocallySignedCert#ca_private_key_pem}
    */
    readonly caPrivateKeyPem: string;
    /**
    * PEM-encoded certificate request
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/tls/r/locally_signed_cert#cert_request_pem LocallySignedCert#cert_request_pem}
    */
    readonly certRequestPem: string;
    /**
    * Number of hours before the certificates expiry when a new certificate will be generated
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/tls/r/locally_signed_cert#early_renewal_hours LocallySignedCert#early_renewal_hours}
    */
    readonly earlyRenewalHours?: number;
    /**
    * Whether the generated certificate will be usable as a CA certificate
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/tls/r/locally_signed_cert#is_ca_certificate LocallySignedCert#is_ca_certificate}
    */
    readonly isCaCertificate?: boolean | cdktf.IResolvable;
    /**
    * If true, the generated certificate will include a subject key identifier.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/tls/r/locally_signed_cert#set_subject_key_id LocallySignedCert#set_subject_key_id}
    */
    readonly setSubjectKeyId?: boolean | cdktf.IResolvable;
    /**
    * Number of hours that the certificate will remain valid for
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/tls/r/locally_signed_cert#validity_period_hours LocallySignedCert#validity_period_hours}
    */
    readonly validityPeriodHours: number;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/tls/r/locally_signed_cert tls_locally_signed_cert}
*/
export declare class LocallySignedCert extends cdktf.TerraformResource {
    static readonly tfResourceType: string;
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/tls/r/locally_signed_cert tls_locally_signed_cert} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options LocallySignedCertConfig
    */
    constructor(scope: Construct, id: string, config: LocallySignedCertConfig);
    private _allowedUses?;
    get allowedUses(): string[];
    set allowedUses(value: string[]);
    get allowedUsesInput(): string[] | undefined;
    private _caCertPem?;
    get caCertPem(): string;
    set caCertPem(value: string);
    get caCertPemInput(): string | undefined;
    private _caKeyAlgorithm?;
    get caKeyAlgorithm(): string;
    set caKeyAlgorithm(value: string);
    get caKeyAlgorithmInput(): string | undefined;
    private _caPrivateKeyPem?;
    get caPrivateKeyPem(): string;
    set caPrivateKeyPem(value: string);
    get caPrivateKeyPemInput(): string | undefined;
    get certPem(): string;
    private _certRequestPem?;
    get certRequestPem(): string;
    set certRequestPem(value: string);
    get certRequestPemInput(): string | undefined;
    private _earlyRenewalHours?;
    get earlyRenewalHours(): number;
    set earlyRenewalHours(value: number);
    resetEarlyRenewalHours(): void;
    get earlyRenewalHoursInput(): number | undefined;
    get id(): string;
    private _isCaCertificate?;
    get isCaCertificate(): boolean | cdktf.IResolvable;
    set isCaCertificate(value: boolean | cdktf.IResolvable);
    resetIsCaCertificate(): void;
    get isCaCertificateInput(): boolean | cdktf.IResolvable | undefined;
    get readyForRenewal(): cdktf.IResolvable;
    private _setSubjectKeyId?;
    get setSubjectKeyId(): boolean | cdktf.IResolvable;
    set setSubjectKeyId(value: boolean | cdktf.IResolvable);
    resetSetSubjectKeyId(): void;
    get setSubjectKeyIdInput(): boolean | cdktf.IResolvable | undefined;
    get validityEndTime(): string;
    private _validityPeriodHours?;
    get validityPeriodHours(): number;
    set validityPeriodHours(value: number);
    get validityPeriodHoursInput(): number | undefined;
    get validityStartTime(): string;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
